==> breeze_website_builder_5.4.54.tar.gz: connect/config.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 2/6/2012	ELL
//

// Special note about changing folders from defaults: Paths to images, CSS or scripts might not translate 100% correctly for templates
// if you change from the default locations.  This can be corrected by editing locations, although it could be quite tedious and not
// necessarily obvious to non-web developers.  If you wish for your site to appear as your domain name without showing any folders in
// the address bar of the browser, you can set BWB_BASE_DIR and BWB_WEBPAGE_DIR to ''.  All other folder defaults must have some
// non-empty name for the system to work properly.

// *** Site Base Folder ***
// Do not include leading or trailing slashes.  For web root level leave empty.
// Examples:
//    Webroot:        ''
//    Folder:         'mywebsitefolder'
//    Nested folders: 'mywebsitefolder/mywebsitesubfolder'
define('BWB_BASE_DIR', '');

// *** Webpage Folder ***
// Leave empty for webroot, i.e.   ''
define('BWB_WEBPAGE_DIR', '');

// *** Image Folder ***
// Cannot be empty.
define('BWB_IMAGE_DIR', 'images');

// *** CSS Folder ***
// Cannot be empty.
define('BWB_CSS_DIR', 'css');

// *** Flash Folder ***
// Cannot be empty.
define('BWB_FLASH_DIR', 'flash');

// *** Media Folder ***
// Cannot be empty.
define('BWB_MEDIA_DIR', 'media');

// *** Scripts Folder ***
// Cannot be empty.
define('BWB_SCRIPTS_DIR', 'scripts');

// *** Table Prefix ***
// You may want to use a table prefix, especially if the Breeze Website Builder must share the same database as another application.
// Include an underscore if your table names will have a prefix with an underscore.  This is more typical of table prefixes.
// i.e.    'bwb_'
define('BWB_TABLE_PREFIX', 'bwb_');

// *** Require SSL ***
// 0 = SSL not required
// 1 = SSL required.
// If set, going to http://mywebsite.com/manage will automatically forward to https://mywebsite.com/manage
define('BWB_REQUIRE_SSL', 0);

// *** Salt ***
// Random string to salt password.  You may change this, BUT be logged in as an administrator. You will need to change
// all of your BWB passwords immediately upon uploading the new config file AND you won't be able to login to do this.
define('BWB_SALT', '!oeghFD87@');

// *** Salt ***
// Random string to salt passwords used for required login pages on website.  You may change this, BUT you will need to 
// change all of your users' passwords immediately upon uploading the new config file. Your users will not be able to login
// until their passwords have been re-created.
define('BWB_PUB_SALT', '#uePYdf78C');

// *** S/N ***
// This site's Breeze Website Builder serial number
define('BWB_SN', '255.255.255.255-1');

// *** Search Engine Friendly (SEF) URLs ***
// 0 = off
// 1 = on
// When on, menu generator produces links without .php. Need to uncomment lines in .htaccss file pertaining to mod rewrite.
define('SEF_URL', 0);

// *** Session Save Path ***
define('SESSION_SAVE_PATH', '/tmp');
// Session save path is not defined on all servers by default.  Default path on most severs is /tmp, but you may need to change
// this path to a folder within your hosting account for example. Note: do not use trailing slash '/'.
?>

==> breeze_website_builder_6.1.20.tar.gz: connect/config.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 2/6/2012	ELL
//

// Special note about changing folders from defaults: Paths to images, CSS or scripts might not translate 100% correctly for templates
// if you change from the default locations.  This can be corrected by editing locations, although it could be quite tedious and not
// necessarily obvious to non-web developers.  If you wish for your site to appear as your domain name without showing any folders in
// the address bar of the browser, you can set BWB_BASE_DIR and BWB_WEBPAGE_DIR to ''.  All other folder defaults must have some
// non-empty name for the system to work properly.

// *** Site Base Folder ***
// Do not include leading or trailing slashes.  For web root level leave empty.
// Examples:
//    Webroot:        ''
//    Folder:         'mywebsitefolder'
//    Nested folders: 'mywebsitefolder/mywebsitesubfolder'
define('BWB_BASE_DIR', '');

// *** Webpage Folder ***
// Leave empty for webroot, i.e.   ''
define('BWB_WEBPAGE_DIR', '');

// *** Image Folder ***
// Cannot be empty.
define('BWB_IMAGE_DIR', 'images');

// *** CSS Folder ***
// Cannot be empty.
define('BWB_CSS_DIR', 'css');

// *** Flash Folder ***
// Cannot be empty.
define('BWB_FLASH_DIR', 'flash');

// *** Media Folder ***
// Cannot be empty.
define('BWB_MEDIA_DIR', 'media');

// *** Scripts Folder ***
// Cannot be empty.
define('BWB_SCRIPTS_DIR', 'scripts');

// *** Fonts Folder ***
// Cannot be empty.
define('BWB_FONTS_DIR', 'fonts');

// *** Table Prefix ***
// You may want to use a table prefix, especially if the Breeze Website Builder must share the same database as another application.
// Include an underscore if your table names will have a prefix with an underscore.  This is more typical of table prefixes.
// i.e.    'bwb_'
define('BWB_TABLE_PREFIX', 'bwb_');

// *** Require SSL ***
// 0 = SSL not required
// 1 = SSL required.
// If set, going to http://mywebsite.com/manage will automatically forward to https://mywebsite.com/manage
define('BWB_REQUIRE_SSL', 0);

// *** Salt ***
// Random string to salt password.  You may change this, BUT be logged in as an administrator. You will need to change
// all of your BWB passwords immediately upon uploading the new config file AND you won't be able to login to do this.
define('BWB_SALT', '!oegTGFhFD87@');

// *** Salt ***
// Random string to salt passwords used for required login pages on website.  You may change this, BUT you will need to 
// change all of your users' passwords immediately upon uploading the new config file. Your users will not be able to login
// until their passwords have been re-created.
define('BWB_PUB_SALT', '#uePYd%3f78C');

// *** S/N ***
// This site's Breeze Website Builder serial number
define('BWB_SN', '255.255.255.255-1');

// *** Search Engine Friendly (SEF) URLs ***
// 0 = off
// 1 = on
// When on, menu generator produces links without .php. Need to uncomment lines in .htaccss file pertaining to mod rewrite.
define('SEF_URL', 0);

// *** Session Save Path ***
define('SESSION_SAVE_PATH', '/tmp');
// Session save path is not defined on all servers by default.  Default path on most severs is /tmp, but you may need to change
// this path to a folder within your hosting account for example. Note: do not use trailing slash '/'.

// *** Language ***
define('BWB_LANG', 'en');
?>
